@@ -115,8 +115,10 @@ void Lib::SoundThread::Run(){
 			ting::Mutex::LockerUnlocker mut(this->chPoolMutex);//lock mutex
 //			TRACE(<< "chPoolToAdd.size() = " << this->chPoolToAdd.size() << std::endl)
 			while(this->chPoolToAdd.size() != 0){
-				this->chPool.push_back(this->chPoolToAdd.front());
+				ting::Ref<aumiks::Channel> ch = this->chPoolToAdd.front();
 				this->chPoolToAdd.pop_front();
+				this->chPool.push_back(ch);
+				ch->OnStart();//notify channel that it was just started
 			}
 		}
 
